@@ -3,13 +3,13 @@
 
 import warnings
 warnings.filterwarnings('ignore')
-
+import cython
 try:
     import pyximport; pyximport.install()
     import cal
 except:
     from alacorder import alac as cal
-
+import os
 import sys
 import click
 import pandas as pd
@@ -33,18 +33,26 @@ pd.set_option('display.max_rows', 100)
 @click.option('--compress','-z', default=False, is_flag=True,
               help="Compress exported file (archives compress with or without flag)")
 @click.option('--overwrite', '-o', default=False, help="Overwrite existing files at output path", is_flag=True,show_default=False)
-@click.option('--launch', '-l', default=False, is_flag=True, help="Launch export in default application", show_default=False)
 @click.option('--no-log','-q','log', default=False, is_flag=True, help="Don't print logs or progress to console")
 @click.option('--no-write','-n', default=False, is_flag=True, help="Do not export to output path", hidden=True)
 @click.option('--no-prompt', '-p', default=False, is_flag=True, help="Skip user input / confirmation prompts")
 @click.option('--debug','-d', default=False, is_flag=True, help="Print extensive logs to console for developers")
 @click.option('--no-batch','-b', default=False, is_flag=True, help="Process all inputs as one batch")
-def cli(input_path, output_path, count, table, archive, overwrite, launch, dedupe, log, no_write, no_prompt, debug, no_batch,
+def cli(input_path, output_path, count, table, archive, overwrite, dedupe, log, no_write, no_prompt, debug, no_batch,
         compress):
 
     log = not log 
 
-    show_options_menu = True if table is None and no_prompt == False and count == 0 and overwrite == False and launch == False and dedupe == False and log == True and no_write == False and no_prompt == False and debug == False and no_batch == False and compress == False else False
+    show_options_menu = True if no_prompt == False and overwrite == False and dedupe == True and log == True and no_write == False and no_prompt == False and debug == False and no_batch == False and compress == False else False
+
+    # assume archive if .zip and no table spec
+    if table == "" or table == None and archive != True and os.path.splitext(output_path)[1] == ".zip":
+        archive = True
+        if log or debug:
+            click.echo("Defaulting to archive... To reconfigure in tables mode, specify table with --table flag.")
+
+    if archive == True:
+        table == ""
 
     # suppress tracebacks unless debug
     if not debug:
@@ -52,7 +60,7 @@ def cli(input_path, output_path, count, table, archive, overwrite, launch, dedup
         warnings.filterwarnings('ignore')
 
     # fix double zip
-    output_path = output_path.replace(".zip","")
+    # output_path = output_path.replace(".zip","")
 
     # inputs - configure and log
     inputs = cal.setinputs(input_path)
@@ -118,9 +126,6 @@ def cli(input_path, output_path, count, table, archive, overwrite, launch, dedup
             elif p == "overwrite" or p == "--overwrite" or p == "-o":
                 overwrite = click.prompt(
                     "Should Alacorder OVERWRITE any existing files at output file paths? [y/N]", type=bool)
-            elif p == "launch" or p == "--launch":
-                launch = click.prompt("Should Alacorder attempt to launch exported files once complete? [y/N]",
-                                      type=bool)
             elif p == "dedupe" or p == "--dedupe" or p == "ignore" or p == "--ignore":
                 dedupe = click.prompt("Should Alacorder remove duplicate cases from outputs? [y/N]",
                                       type=bool)
@@ -152,7 +157,7 @@ def cli(input_path, output_path, count, table, archive, overwrite, launch, dedup
                 click.echo(p)
 
     # finalize config
-    cf = cal.set(inputs, outputs, count=count, table=table, overwrite=overwrite, launch=launch, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress)
+    cf = cal.set(inputs, outputs, count=count, table=table, overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress)
 
     if debug:
         click.echo(cf)
