@@ -7,6 +7,7 @@ import math
 import os
 import re
 import sys
+import datetime
 import time
 import warnings
 import PyPDF2
@@ -260,7 +261,6 @@ def charges(conf):
         sys.tracebacklimit = 0
         warnings.filterwarnings('ignore')
     queue = conf['QUEUE']
-    table = conf['TABLE']
     conf.DEDUPE = conf['DEDUPE']
     from_archive = True if conf['IS_FULL_TEXT'] else False
 
@@ -784,7 +784,7 @@ def setinputs(path, debug=False):
         warnings.filterwarnings('ignore')
         sys.tracebacklimit = 0
 
-    if isinstance(path, pd.core.frame.DataFrame):
+    if isinstance(path, pd.core.frame.DataFrame) or isinstance(path, pd.core.series.Series):
         if "AllPagesText" in path.columns and path.shape[0] > 0:
             queue = path['AllPagesText']
             is_full_text = True
@@ -807,7 +807,9 @@ def setinputs(path, debug=False):
             is_full_text = True
             found = len(queue)
         elif os.path.isfile(path) and (os.path.splitext(path)[1] == ".zip"):
-            nozipext = os.path.splitext(os.path.splitext(path)[0])[1]
+            nzpath = path.replace(".zip","")
+            nozipext = os.path.splitext(nzpath)[1]
+            logdebug(nozipext)
             if nozipext == ".json":
                 pickle = pd.read_json(path, orient='table',compression="zip")
                 queue = pickle['AllPagesText']
@@ -833,7 +835,10 @@ def setinputs(path, debug=False):
                 found = len(queue)
                 good = True
         elif os.path.isfile(path) and os.path.splitext(path)[1] == ".json":
-            pickle = pd.read_json(path, orient='table')
+            try:
+                pickle = pd.read_json(path, orient='table')
+            except:
+                pickle = pd.read_json(path, orient='table',compression="zip")
             queue = pickle['AllPagesText']
             is_full_text = True
             found = len(queue)
@@ -862,13 +867,11 @@ def setinputs(path, debug=False):
         good = False
 
     if good:
-        echo = click.style(f"\nFound {found} cases in input.", italic=True, fg='bright_yellow')
+        echo = click.style(f"Found {found} cases in input.", italic=True, fg='bright_yellow')
     else:
         echo = click.style(
             f"""Alacorder failed to configure input! Try again with a valid PDF directory or full text archive path, or run 'python -m alacorder --help' in command line for more details.""",
             fg='red', bold=True)
-        if not debug:
-            raise Exception("Alacorder failed and quit.")
 
     out = pd.Series({
         'INPUT_PATH': path,
@@ -893,6 +896,11 @@ def setoutputs(path="", debug=False, archive=False,table=""):
         warnings.filterwarnings('ignore')
         sys.tracebacklimit = 0
 
+    if ".zip" in path or ".xz" in path:
+        compress=True
+    
+    nzpath = path.replace(".zip","")
+
     # if no output -> set default
     if path == "" and archive == False:
         path = "NONE"
@@ -900,9 +908,7 @@ def setoutputs(path="", debug=False, archive=False,table=""):
         make == "multiexport" if table != "cases" and table != "charges" and table != "fees" and table != "disposition" and table != "filing" else "singletable"
         good = True
         exists = False
-        echo = click.style(
-                f"""Output successfully configured for {"table" if (make == "multiexport" or make == "singletable") else "archive"} export.\n""",
-                italic=True, fg='bright_yellow')
+        echo = click.style(f"Output successfully configured.", italic=True, fg='bright_yellow')
     if path == "" and archive == True:
         path = "NONE"
         ext = "NONE"
@@ -910,7 +916,7 @@ def setoutputs(path="", debug=False, archive=False,table=""):
         good = True
         exists = False
         echo = click.style(
-                f"""Output successfully configured for {"table" if make == "multiexport" or make == "singletable" else "archive"} export.\n""",
+                f"""Output successfully configured for {"table" if make == "multiexport" or make == "singletable" else "archive"} export.""",
                 italic=True, fg='bright_yellow')
     # if path
     if isinstance(path, str) and path != "NONE":
@@ -937,7 +943,7 @@ def setoutputs(path="", debug=False, archive=False,table=""):
 
         if good:
             echo = click.style(
-                f"""Output path successfully configured for {"table" if (make == "multiexport" or make == "singletable") else "archive"} export.\n""",
+                f"""Output path successfully configured for {"table" if (make == "multiexport" or make == "singletable") else "archive"} export.""",
                 italic=True, fg='bright_yellow')
         else:
             echo = click.style(
@@ -945,7 +951,8 @@ def setoutputs(path="", debug=False, archive=False,table=""):
                 fg='red', bold=True)
 
     out = pd.Series({
-        'OUTPUT_PATH': path,
+        'OUTPUT_PATH': nzpath,
+        'ZIP_OUTPUT_PATH': path,
         'OUTPUT_EXT': ext,
         'MAKE': make,
         'GOOD': good,
@@ -956,10 +963,7 @@ def setoutputs(path="", debug=False, archive=False,table=""):
     return out
 
 
-def set(inputs, outputs=None, count=0, table='', overwrite=False, launch=False, log=True, dedupe=False, no_write=False,
-        no_prompt=False, skip_echo=False, debug=False, no_batch=False, compress=False):
-    # inputs = setinputs(inputs)
-    # outputs = setoutputs(outputs)
+def set(inputs, outputs=None, count=0, table='', overwrite=False, log=True, dedupe=False, no_write=False, no_prompt=False, skip_echo=False, debug=False, no_batch=False, compress=False):
 
     status_code = []
     echo = ""
@@ -991,16 +995,19 @@ def set(inputs, outputs=None, count=0, table='', overwrite=False, launch=False,
     else:
         queue = inputs.QUEUE
 
-    echo += echo_conf(inputs.INPUT_PATH, outputs.MAKE, outputs.OUTPUT_PATH, overwrite, no_write, dedupe, launch,
+    echo += echo_conf(inputs.INPUT_PATH, outputs.MAKE, outputs.OUTPUT_PATH, overwrite, no_write, dedupe,
                       no_prompt, compress)
 
     if outputs.COMPRESS == True:
         compress = True
 
+    cftime = time.time()
+
     out = pd.Series({
         'GOOD': good,
         'ECHO': echo,
         'STATUS_CODES': status_code,
+        'TIME': cftime,
 
         'QUEUE': queue,
         'COUNT': count,
@@ -1017,7 +1024,6 @@ def set(inputs, outputs=None, count=0, table='', overwrite=False, launch=False,
 
         'DEDUPE': dedupe,
         'LOG': log,
-        'LAUNCH': launch,
         'DEBUG': debug,
         'NO_PROMPT': no_prompt,
         'NO_WRITE': no_write,
@@ -1044,7 +1050,7 @@ def batcher(conf):
 
 
 # same as calling set(setinputs(path), setoutputs(path), **kwargs)
-def setpaths(input_path, output_path=None, count=0, table='', overwrite=False, launch=False, log=True, dedupe=False,
+def setpaths(input_path, output_path=None, count=0, table='', overwrite=False, log=True, dedupe=False,
              no_write=False, no_prompt=False, skip_echo=False, debug=False, no_batch=False, compress=False):
     if not debug:
         sys.tracebacklimit = 0
@@ -1057,13 +1063,16 @@ def setpaths(input_path, output_path=None, count=0, table='', overwrite=False, l
         compress = True
     if log:
         click.secho(b.ECHO)
-    c = set(a, b, count=count, table=table, overwrite=overwrite, launch=launch, log=log, dedupe=dedupe,
+    c = set(a, b, count=count, table=table, overwrite=overwrite, log=log, dedupe=dedupe,
             no_write=no_write, no_prompt=no_prompt, debug=debug, no_batch=no_batch, compress=compress)
     if log:
         click.secho(c.ECHO)
     return c
 
-
+def setinit(input_path, output_path=None, archive=False,count=0, table='', overwrite=False, log=True, dedupe=False, no_write=False, no_prompt=False, debug=False, no_batch=False, compress=False):
+    a = setpaths(input_path=input_path, output_path=output_path, archive=archive, count=count, table=table, overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt,debug=debug, no_batch=no_batch, compress=compress)
+    b = init(a)
+    return b
 
 ## GETTERS
 
@@ -1663,6 +1672,46 @@ def getCharges(text: str):
             charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes,
             conv_codes, allcharge, charges]
 
+def getCaseYear(text):
+    """
+    Return case year 
+    """
+    cnum = getCaseNumber(text)
+    return float(cnum[6:10])
+
+def getCounty(text):
+    """
+    Return county
+    """
+    cnum = getCaseNumber(text)
+    return int(cnum[0:2])
+
+def getLastName(text):
+    """
+    Return last name
+    """
+    name = getName(text)
+    return name.split(" ")[0].strip()
+
+def getFirstName(text):
+    """
+    Return first name
+    """
+    name = getName(text)
+    if len(name.split(" ")) > 1:
+        return name.split(" ")[1].strip()
+    else:
+        return name
+
+def getMiddleName(text):
+    """
+    Return middle name or initial
+    """
+    name = getName(text)
+    if len(name.split(" ")) > 2:
+        return name.split(" ")[2].strip()
+    else:
+        return ""
 
 def getConvictions(text):
     """
@@ -1785,13 +1834,16 @@ def getChargesString(text):
 
 ##  LOGS
 
-def echo_conf(input_path, make, output_path, overwrite, no_write, dedupe, launch, no_prompt, compress):
-    d = click.style(f"""\n* Successfully configured!\n""", fg='green', bold=True)
+def echo_conf(input_path, make, output_path, overwrite, no_write, dedupe, no_prompt, compress):
+    """
+    Logs configuration details to console
+    """
+    d = click.style(f"""* Successfully configured!\n""", fg='green', bold=True)
     e = click.style(
         f"""INPUT: {input_path}\n{'TABLE' if make == "multiexport" or make == "singletable" else 'ARCHIVE'}: {output_path}\n""",
         fg='white', bold=True)
     f = click.style(
-        f"""{"ARCHIVE is enabled. Alacorder will write full text case archive to output path instead of data tables. " if make == "archive" else ''}{"NO-WRITE is enabled. Alacorder will NOT export outputs. " if no_write else ''}{"OVERWRITE is enabled. Alacorder will overwrite existing files at output path! " if overwrite else ''}{"REMOVE DUPLICATES is enabled. At time of export, all duplicate cases will be removed from output. " if dedupe and make == "archive" else ''}{"LAUNCH is enabled. Upon completion, Alacorder will attempt to launch exported file in default viewing application. " if launch and make != "archive" else ''}{"NO_PROMPT is enabled. All user confirmation prompts will be suppressed as if set to default by user." if no_prompt else ''}{"COMPRESS is enabled. Alacorder will try to compress output file." if compress == True and make != "archive" else ''}""".strip(),
+        f"""{"ARCHIVE is enabled. Alacorder will write full text case archive to output path instead of data tables. " if make == "archive" else ''}{"NO-WRITE is enabled. Alacorder will NOT export outputs. " if no_write else ''}{"OVERWRITE is enabled. Alacorder will overwrite existing files at output path! " if overwrite else ''}{"REMOVE DUPLICATES is enabled. At time of export, all duplicate cases will be removed from output. " if dedupe and make == "archive" else ''}{"NO_PROMPT is enabled. All user confirmation prompts will be suppressed as if set to default by user." if no_prompt else ''}{"COMPRESS is enabled. Alacorder will try to compress output file." if compress == True else ''}""".strip(),
         italic=True, fg='white')
     return d + e + f
 
@@ -1804,7 +1856,6 @@ Select preferred table output below.
     E:  Charges (filing only)
 
 Enter A, B, C, D, or E to continue.
-
 ''')
 
 
@@ -1817,7 +1868,6 @@ ujust_table = ('''
 EXPORT DATA TABLE: To export data table from case inputs, enter full output path. Use .xls or .xlsx to export all tables, or, if using another format (.csv, .json, .dta), select a table after entering output file path.
 
 Enter path.
-
 ''')
 
 
@@ -1832,7 +1882,6 @@ EXPORT FULL TEXT ARCHIVE: To process case inputs into a full text archive (recom
 EXPORT DATA TABLE: To export data table from case inputs, enter full output path. Use .xls or .xlsx to export all tables, or, if using another format (.csv, .json, .dta), select a table after entering output file path.
 
 Enter path.
-
 ''')
 
 
@@ -1844,11 +1893,12 @@ utitle = click.style("\nALACORDER beta 75",bold=True,italic=True) + """
 
 Alacorder processes case detail PDFs into data tables suitable for research purposes. Alacorder also generates compressed text archives from the source PDFs to speed future data collection from the same set of cases.
 
-ACCEPTED      /pdfs/path/   PDF directory           
-INPUTS:       .pkl.xz       Compressed archive      
+    ACCEPTED      /pdfs/path/   PDF directory           
+    INPUTS:       .pkl.xz       Compressed pickle archive
+                  .json(.zip)   JSON (-zip flag to compress)
+
 
 Enter input path.
-
 """
 
 
@@ -1859,7 +1909,6 @@ def title():
 utext_p = ('''
 
 Enter path to output text file (must be .txt). 
-
 ''')
 
 
@@ -1867,18 +1916,22 @@ def text_p():
     return click.style(utext_p, bold=True)
 
 
-
 def title():
     return utitle
 
 def complete(conf, *outputs):
+    """
+    Logs completion
+    """
+    elapsed = math.floor(time.time() - conf.TIME)
+
     if not conf.DEBUG:
         sys.tracebacklimit = 0
         warnings.filterwarnings('ignore')
     if conf.LOG and len(outputs) > 0:
         click.secho(outputs)
     if conf.LOG:
-        click.secho("\n\n* Task completed!\n\n", bold=True, fg='green')
+        click.secho(f"\n* Task completed in {elapsed} seconds.", bold=True, fg='green')
 
 
 def logdebug(conf, *msg):
